CREATE OR REPLACE VIEW public.access_review_summary_v AS 
 SELECT instance.id AS instance_id,
    defn.name,
    defn.description,
    defn.review_type,
    defn.next_schedule_date,
    defn.review_target_spec_json,
    multi_owner.review_owners AS review_inst_owner_display_name,
    instance.status,
    instance.status_comment,
    instance.start_date,
    instance.expected_end_date,
    instance.end_date,
    instance.valid_to_date,
    instance.canceled_by,
    instance.task_count,
    instance.task_complete_count,
    canceler.display_name AS canceled_by_name,
    instance.item_count,
    instances.reviewer_count,
    ( SELECT decisions.decision_count
           FROM ( SELECT inst.id AS instance,
                    it.final_decision AS decision,
                    count(it.final_decision) AS decision_count
                   FROM review_instance inst
                     LEFT JOIN review_item it ON it.review_instance_id = inst.id
                  GROUP BY inst.id, it.final_decision) decisions
          WHERE decisions.instance = instance.id AND decisions.decision::text = 'ASSIGN_USER'::text) AS assign_count,
    ( SELECT decisions.decision_count
           FROM ( SELECT inst.id AS instance,
                    it.final_decision AS decision,
                    count(it.final_decision) AS decision_count
                   FROM review_instance inst
                     LEFT JOIN review_item it ON it.review_instance_id = inst.id
                  GROUP BY inst.id, it.final_decision) decisions
          WHERE decisions.instance = instance.id AND decisions.decision::text = 'KEEP'::text) AS keep_count,
    ( SELECT decisions.decision_count
           FROM ( SELECT inst.id AS instance,
                    it.final_decision AS decision,
                    count(it.final_decision) AS decision_count
                   FROM review_instance inst
                     LEFT JOIN review_item it ON it.review_instance_id = inst.id
                  GROUP BY inst.id, it.final_decision) decisions
          WHERE decisions.instance = instance.id AND decisions.decision::text = 'REMOVE'::text) AS remove_count
   FROM review_instance instance
     JOIN review_definition defn ON instance.review_definition = defn.id
     JOIN ( SELECT inst.id AS instance,
            count(DISTINCT rui.unique_user_id) AS reviewer_count
           FROM review_instance inst
             LEFT JOIN reviewer_instance ri ON ri.review_instance_id = inst.id
             LEFT JOIN reviewer_user_instance rui ON rui.reviewer_instance_id = ri.id
          GROUP BY inst.id) instances ON instances.instance = instance.id
     LEFT JOIN suser canceler ON instance.canceled_by::text = canceler.unique_user_id::text AND canceler.effective = true
     LEFT JOIN reviewer_instance rev_owner ON instance.id = rev_owner.review_instance_id AND rev_owner.type::text = 'RO'::text
     LEFT JOIN suser review_owner ON rev_owner.single_reviewer_unique_id::text = review_owner.unique_user_id::text AND review_owner.effective = true
     LEFT JOIN ( SELECT DISTINCT defn_1.name AS review_name,
            ri.id AS rid,
            string_agg(s.display_name::text, ' | '::text) AS review_owners
           FROM review_instance ri
             JOIN review_definition defn_1 ON ri.review_definition = defn_1.id
             LEFT JOIN reviewer_instance rev_owner_1 ON ri.id = rev_owner_1.review_instance_id AND rev_owner_1.type::text = 'RO'::text
             LEFT JOIN reviewer_user_instance rui ON rui.reviewer_instance_id = rev_owner_1.id
             LEFT JOIN suser s ON rui.unique_user_id::text = s.unique_user_id::text AND s.effective = true
          GROUP BY defn_1.name, ri.id) multi_owner ON multi_owner.rid = instance.id
  WHERE defn.deleted = false;

ALTER TABLE public.access_review_summary_v
  OWNER TO igops;
GRANT ALL ON TABLE public.access_review_summary_v TO igops;
GRANT SELECT ON TABLE public.access_review_summary_v TO ig_report_role;
